==> 0.0.2.tar.gz: lib/settings/theme_settings.dart <==
import 'package:particle_ui/particle.dart';

class ThemeSettings {
  final Map<FontType, Font> fonts;
  final Map<IconDataType, IconData> iconData;
  final Map<FillType, Fill> fills;

  final Map<TextType, Text> texts;
  //final Map<IconType, Icon> icons;
  //final Map<DividerType, Divider> dividers;

  factory ThemeSettings({
    Map<FontType, Font> fonts,
    Map<IconDataType, IconData> iconData,
    Map<FillType, Fill> fills,

    Map<TextType, Text> texts,
    //Map<IconType, Icon> icons,
    //Map<DividerType, Divider> dividers,
  }) {

    //START of UI Attributes

    fonts ??= {
      FontType.headline1: Font(fontSize: 96, fontWeight: FontWeight.w300, letterSpacing: -1.5),
      FontType.headline2: Font(fontSize: 60, fontWeight: FontWeight.w300, letterSpacing: -.5),
      FontType.headline3: Font(fontSize: 48, fontWeight: FontWeight.normal),
      FontType.headline4: Font(fontSize: 34, fontWeight: FontWeight.normal, letterSpacing: .25),
      FontType.headline5: Font(fontSize: 24, fontWeight: FontWeight.normal),
      FontType.headline6: Font(fontSize: 20, fontWeight: FontWeight.w500, letterSpacing: .15),
      FontType.subtitle1: Font(fontSize: 16, fontWeight: FontWeight.w500, letterSpacing: .15),
      FontType.subtitle2: Font(fontSize: 14, fontWeight: FontWeight.normal, letterSpacing: .1),
      FontType.body1: Font(fontSize: 16, fontWeight: FontWeight.normal, letterSpacing: .5),
      FontType.body2: Font(fontSize: 14, fontWeight: FontWeight.normal, letterSpacing: .25),
      FontType.button: Font(fontSize: 14, fontWeight: FontWeight.w500, letterSpacing: 1.25),
      FontType.footnote: Font(fontSize: 13, fontWeight: FontWeight.normal),
      FontType.caption1: Font(fontSize: 12, fontWeight: FontWeight.normal, letterSpacing: .4),
      FontType.caption2: Font(fontSize: 11, fontWeight: FontWeight.normal)
    };

    iconData ??= {
      IconDataType.add: SvgIcon('<svg xmlns="http://www.w3.org/2000/svg" width="48" height="48" viewBox="0 0 48 48"><path d="M38 26H26v12h-4V26H10v-4h12V10h4v12h12v4z"/></svg>'),
      IconDataType.home: SvgIcon('<svg xmlns="http://www.w3.org/2000/svg" width="48" height="48" viewBox="0 0 48 48"><path d="M20 40V28h8v12h10V24h6L24 6 4 24h6v16z"/></svg>'),
      IconDataType.search: SvgIcon('<svg xmlns="http://www.w3.org/2000/svg" width="48" height="48" viewBox="0 0 48 48"><path d="M31 28h-1.59l-.55-.55C30.82 25.18 32 22.23 32 19c0-7.18-5.82-13-13-13S6 11.82 6 19s5.82 13 13 13c3.23 0 6.18-1.18 8.45-3.13l.55.55V31l10 9.98L40.98 38 31 28zm-12 0c-4.97 0-9-4.03-9-9s4.03-9 9-9 9 4.03 9 9-4.03 9-9 9z"/></svg>')
    };

    fills ??= {
      FillType.background: Colors.white,
      FillType.onBackground: Color('000000', opacity: Opacities.opacity95),
      FillType.surface: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.onSurface: Color('000000', opacity: Opacities.opacity95),
      FillType.primary: LinearGradient(
        begin: Alignments.topLeft, end: Alignments.bottomRight,
        colors: [Color('BDBDBD', opacity: Opacity(.85)), Color('FAFAFA', opacity: Opacity(.85))]),
      //FillType.primaryVariant1:
      FillType.onPrimary: Color('000000', opacity: Opacities.opacity95),
      FillType.secondary: Color('0074B1', opacity: Opacities.opacity95),
      FillType.onSecondary: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.success: Color('8BC34A', opacity: Opacities.opacity95),
      FillType.onSuccess: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.info: Color('03A9F4', opacity: Opacities.opacity95),
      FillType.onInfo: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.warning: Color('FF9800', opacity: Opacities.opacity95),
      FillType.onWarning: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.error: Color('F44336', opacity: Opacities.opacity95),
      FillType.onError: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.line: Color('000000', opacity: Opacities.opacity5)
    };


    //START of UI Components

    texts ??= {
      TextType.headline1: Text(null, font: fonts[FontType.headline1], fill: fills[FillType.onSurface]),
      TextType.headline2: Text(null, font: fonts[FontType.headline2], fill: fills[FillType.onSurface]),
      TextType.headline3: Text(null, font: fonts[FontType.headline3], fill: fills[FillType.onSurface]),
      TextType.headline4: Text(null, font: fonts[FontType.headline4], fill: fills[FillType.onSurface]),
      TextType.headline5: Text(null, font: fonts[FontType.headline5], fill: fills[FillType.onSurface]),
      TextType.headline6: Text(null, font: fonts[FontType.headline6], fill: fills[FillType.onSurface]),
      TextType.subtitle1: Text(null, font: fonts[FontType.subtitle1], fill: fills[FillType.onSurface]),
      TextType.subtitle2: Text(null, font: fonts[FontType.subtitle2], fill: fills[FillType.onSurface]),
      TextType.body1: Text(null, font: fonts[FontType.body1], fill: fills[FillType.onSurface]),
      TextType.body2: Text(null, font: fonts[FontType.body2], fill: fills[FillType.onSurface]),
      TextType.button: Text(null, font: fonts[FontType.button], fill: fills[FillType.onSurface]),
      TextType.footnote: Text(null, font: fonts[FontType.footnote], fill: fills[FillType.onSurface]),
      TextType.caption1: Text(null, font: fonts[FontType.caption1], fill: fills[FillType.onSurface]),
      TextType.caption2: Text(null, font: fonts[FontType.caption2], fill: fills[FillType.onSurface]),
    };

    /*icons ??= {
      IconType.tiny: Icon(null, size: 12, fill: fills[FillType.onSurface]),
      IconType.xsmall: Icon(null, size: 14, fill: fills[FillType.onSurface]),
      IconType.small: Icon(null, size: 16, fill: fills[FillType.onSurface]),
      IconType.medium: Icon(null, size: 24, fill: fills[FillType.onSurface]),
      IconType.large: Icon(null, size: 32, fill: fills[FillType.onSurface]),
      IconType.xlarge: Icon(null, size: 48, fill: fills[FillType.onSurface]),
      IconType.big: Icon(null, size: 56, fill: fills[FillType.onSurface]),
    };

    dividers ??= {
      DividerType.thinnest: Divider(thickness: 1.0, fill: fills[FillType.line]),
      DividerType.thinner: Divider(thickness: 2.0, fill: fills[FillType.line]),
      DividerType.thin: Divider(thickness: 4.0, fill: fills[FillType.line]),
      DividerType.thick: Divider(thickness: 8.0, fill: fills[FillType.line]),
      DividerType.thicker: Divider(thickness: 16.0, fill: fills[FillType.line]),
      DividerType.thickest: Divider(thickness: 24.0, fill: fills[FillType.line]),
    };*/


    return ThemeSettings.raw(
      fonts: fonts,
      iconData: iconData,
      fills: fills,

      texts: texts,
      //icons: icons,
      //dividers: dividers,
    );
  }

  factory ThemeSettings.fallback() => ThemeSettings();

  ThemeSettings.raw({
    this.fonts,
    this.iconData,
    this.fills,

    this.texts,
    //this.icons,
    //this.dividers,
  });
}

==> 0.0.4.tar.gz: lib/settings/theme_settings.dart <==
import 'package:particle_ui/particle.dart';

class ThemeSettings {
  final Map<FontType, Font> fonts;
  final Map<IconDataType, IconData> iconData;
  final Map<FillType, Fill> fills;

  final Map<TextType, Text> texts;
  //final Map<IconType, Icon> icons;
  final Map<DividerType, Divider> dividers;

  factory ThemeSettings({
    Map<FontType, Font> fonts,
    Map<IconDataType, IconData> iconData,
    Map<FillType, Fill> fills,

    Map<TextType, Text> texts,
    //Map<IconType, Icon> icons,
    Map<DividerType, Divider> dividers,
  }) {

    //START of UI Attributes

    fonts ??= {
      FontType.headline1: Font(fontSize: 96, fontWeight: FontWeight.w300, letterSpacing: -1.5),
      FontType.headline2: Font(fontSize: 60, fontWeight: FontWeight.w300, letterSpacing: -.5),
      FontType.headline3: Font(fontSize: 48, fontWeight: FontWeight.normal),
      FontType.headline4: Font(fontSize: 34, fontWeight: FontWeight.normal, letterSpacing: .25),
      FontType.headline5: Font(fontSize: 24, fontWeight: FontWeight.normal),
      FontType.headline6: Font(fontSize: 20, fontWeight: FontWeight.w500, letterSpacing: .15),
      FontType.subtitle1: Font(fontSize: 16, fontWeight: FontWeight.w500, letterSpacing: .15),
      FontType.subtitle2: Font(fontSize: 14, fontWeight: FontWeight.normal, letterSpacing: .1),
      FontType.body1: Font(fontSize: 16, fontWeight: FontWeight.normal, letterSpacing: .5),
      FontType.body2: Font(fontSize: 14, fontWeight: FontWeight.normal, letterSpacing: .25),
      FontType.button: Font(fontSize: 14, fontWeight: FontWeight.w500, letterSpacing: 1.25),
      FontType.footnote: Font(fontSize: 13, fontWeight: FontWeight.normal),
      FontType.caption1: Font(fontSize: 12, fontWeight: FontWeight.normal, letterSpacing: .4),
      FontType.caption2: Font(fontSize: 11, fontWeight: FontWeight.normal)
    };

    iconData ??= {
      IconDataType.add: SvgIcon('<svg xmlns="http://www.w3.org/2000/svg" width="48" height="48" viewBox="0 0 48 48"><path d="M38 26H26v12h-4V26H10v-4h12V10h4v12h12v4z"/></svg>'),
      IconDataType.home: SvgIcon('<svg xmlns="http://www.w3.org/2000/svg" width="48" height="48" viewBox="0 0 48 48"><path d="M20 40V28h8v12h10V24h6L24 6 4 24h6v16z"/></svg>'),
      IconDataType.search: SvgIcon('<svg xmlns="http://www.w3.org/2000/svg" width="48" height="48" viewBox="0 0 48 48"><path d="M31 28h-1.59l-.55-.55C30.82 25.18 32 22.23 32 19c0-7.18-5.82-13-13-13S6 11.82 6 19s5.82 13 13 13c3.23 0 6.18-1.18 8.45-3.13l.55.55V31l10 9.98L40.98 38 31 28zm-12 0c-4.97 0-9-4.03-9-9s4.03-9 9-9 9 4.03 9 9-4.03 9-9 9z"/></svg>')
    };

    fills ??= {
      FillType.background: Colors.white,
      FillType.onBackground: Color('000000', opacity: Opacities.opacity95),
      FillType.surface: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.onSurface: Color('000000', opacity: Opacities.opacity95),
      FillType.primary: LinearGradient(
        begin: Alignments.topLeft, end: Alignments.bottomRight,
        colors: [Color('BDBDBD', opacity: Opacity(.85)), Color('FAFAFA', opacity: Opacity(.85))]),
      //FillType.primaryVariant1:
      FillType.onPrimary: Color('000000', opacity: Opacities.opacity95),
      FillType.secondary: Color('0074B1', opacity: Opacities.opacity95),
      FillType.onSecondary: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.success: Color('8BC34A', opacity: Opacities.opacity95),
      FillType.onSuccess: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.info: Color('03A9F4', opacity: Opacities.opacity95),
      FillType.onInfo: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.warning: Color('FF9800', opacity: Opacities.opacity95),
      FillType.onWarning: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.error: Color('F44336', opacity: Opacities.opacity95),
      FillType.onError: Color('FFFFFF', opacity: Opacities.opacity95),
      FillType.line: Color('000000', opacity: Opacities.opacity5)
    };


    //START of UI Components

    texts ??= {
      TextType.headline1: Text(null, font: fonts[FontType.headline1], fill: fills[FillType.onSurface]),
      TextType.headline2: Text(null, font: fonts[FontType.headline2], fill: fills[FillType.onSurface]),
      TextType.headline3: Text(null, font: fonts[FontType.headline3], fill: fills[FillType.onSurface]),
      TextType.headline4: Text(null, font: fonts[FontType.headline4], fill: fills[FillType.onSurface]),
      TextType.headline5: Text(null, font: fonts[FontType.headline5], fill: fills[FillType.onSurface]),
      TextType.headline6: Text(null, font: fonts[FontType.headline6], fill: fills[FillType.onSurface]),
      TextType.subtitle1: Text(null, font: fonts[FontType.subtitle1], fill: fills[FillType.onSurface]),
      TextType.subtitle2: Text(null, font: fonts[FontType.subtitle2], fill: fills[FillType.onSurface]),
      TextType.body1: Text(null, font: fonts[FontType.body1], fill: fills[FillType.onSurface]),
      TextType.body2: Text(null, font: fonts[FontType.body2], fill: fills[FillType.onSurface]),
      TextType.button: Text(null, font: fonts[FontType.button], fill: fills[FillType.onSurface]),
      TextType.footnote: Text(null, font: fonts[FontType.footnote], fill: fills[FillType.onSurface]),
      TextType.caption1: Text(null, font: fonts[FontType.caption1], fill: fills[FillType.onSurface]),
      TextType.caption2: Text(null, font: fonts[FontType.caption2], fill: fills[FillType.onSurface]),
    };

    /*icons ??= {
      IconType.tiny: Icon(null, size: 12, fill: fills[FillType.onSurface]),
      IconType.xsmall: Icon(null, size: 14, fill: fills[FillType.onSurface]),
      IconType.small: Icon(null, size: 16, fill: fills[FillType.onSurface]),
      IconType.medium: Icon(null, size: 24, fill: fills[FillType.onSurface]),
      IconType.large: Icon(null, size: 32, fill: fills[FillType.onSurface]),
      IconType.xlarge: Icon(null, size: 48, fill: fills[FillType.onSurface]),
      IconType.big: Icon(null, size: 56, fill: fills[FillType.onSurface]),
    };*/

    dividers ??= {
      DividerType.thinnest: Divider(thickness: 1.0, fill: fills[FillType.line]),
      DividerType.thinner: Divider(thickness: 2.0, fill: fills[FillType.line]),
      DividerType.thin: Divider(thickness: 4.0, fill: fills[FillType.line]),
      DividerType.thick: Divider(thickness: 8.0, fill: fills[FillType.line]),
      DividerType.thicker: Divider(thickness: 16.0, fill: fills[FillType.line]),
      DividerType.thickest: Divider(thickness: 24.0, fill: fills[FillType.line]),
    };


    return ThemeSettings.raw(
      fonts: fonts,
      iconData: iconData,
      fills: fills,

      texts: texts,
      //icons: icons,
      dividers: dividers,
    );
  }

  factory ThemeSettings.fallback() => ThemeSettings();

  ThemeSettings.raw({
    this.fonts,
    this.iconData,
    this.fills,

    this.texts,
    //this.icons,
    this.dividers,
  });
}
